#
# spec file for package plasma5-pa
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf5_version 5.98.0
%define qt5_version 5.15.0
%bcond_without released
Name:           plasma5-pa
Version:        5.27.8
Release:        1.1
Summary:        The Plasma5 Volume Manager
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/plasma-pa-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/plasma-pa-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  extra-cmake-modules >= 0.0.14
BuildRequires:  kf5-filesystem
BuildRequires:  libcanberra-devel
BuildRequires:  cmake(KF5CoreAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5Declarative) >= %{kf5_version}
BuildRequires:  cmake(KF5DocTools) >= %{kf5_version}
BuildRequires:  cmake(KF5GlobalAccel) >= %{kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{kf5_version}
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5Notifications) >= %{kf5_version}
BuildRequires:  cmake(KF5Package) >= %{kf5_version}
BuildRequires:  cmake(KF5Plasma) >= %{kf5_version}
BuildRequires:  cmake(KF5WindowSystem) >= %{kf5_version}
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Quick) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libpulse)
Supplements:    (plasma5-desktop and (pulseaudio or pipewire-pulseaudio))
# boo#1092871
Recommends:     (pulseaudio-module-gsettings if pulseaudio)
Requires:       kirigami2 >= %{kf5_version}
Requires:       (pulseaudio-module-x11 or pipewire-pulseaudio)
%if 0%{?suse_version} > 1500
Suggests:       pipewire-pulseaudio
%else
Suggests:       pulseaudio-module-x11
%endif
Recommends:     %{name}-lang

%description
A volume manager plasmoid superseding kmix.

%lang_package

%prep
%autosetup -p1 -n plasma-pa-%{version}

%build
%cmake_kf5 -d build -- -DCMAKE_INSTALL_LOCALEDIR=%{_kf5_localedir} -DUSE_GSETTINGS=TRUE
%cmake_build

%install
%kf5_makeinstall -C build

%kf5_find_lang
%kf5_find_htmldocs

%files
%license LICENSES/*
%{_kf5_applicationsdir}/kcm_pulseaudio.desktop
%{_kf5_plugindir}/
%{_kf5_qmldir}/
%{_kf5_sharedir}/kconf_update/
%{_kf5_sharedir}/kpackage/
%{_kf5_servicesdir}/
%{_kf5_plasmadir}/
%{_kf5_appstreamdir}/
%dir %{_kf5_sharedir}/kde4
%dir %{_kf5_sharedir}/kde4/apps
%dir %{_kf5_sharedir}/kde4/apps/kconf_update
%{_kf5_sharedir}/kde4/apps/kconf_update/disable_kmix.upd
%{_kf5_sharedir}/kde4/apps/kconf_update/plasmaVolumeDisableKMixAutostart.pl
%dir %{_kf5_htmldir}/en
%dir %{_kf5_htmldir}
%doc %{_kf5_htmldir}/en/*/

%files lang -f %{name}.lang

%changelog
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- Changes since 5.27.7:
  * applet: show placeholder message in tooltip when there is no device (kde#469778)
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- Changes since 5.27.6:
  * Put volume change logic centrally in VolumeSlider
  * Make setGenericVolume keep balance between channels (kde#435840)
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- Changes since 5.27.5:
  * applet: Fix crash when opening context menu with no contents (kde#470847)
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- No code changes since 5.27.4
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- Changes since 5.27.3:
  * kcm: stop setting sourceSize in avatar
  * kcm/DeviceListItem: Set width for comboboxes, with correctly sized popup
  * applet: add missing function for "Show virtual devices" menu item (kde#465996)
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- Changes since 5.27.2:
  * kcm: Fix visuals when testing non-standard channel names
  * kcm: Fix missing id and implicit parameter signal handler (kde#466075)
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- No code changes since 5.27.1
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- No code changes since 5.27.0
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- No code changes since 5.26.90
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Changes since 5.26.5:
  * Use ecm_set_disabled_deprecation_versions
  * Update module name for the combine-sink
  * Install translated documentation from po/ too
  * applet: hide current output device from tooltip when it's the only one
  * applet: mention scrollability in tooltip
  * kcm: make volume sliders obey "Raise maximum volume" setting (kde#458977)
  * Make global mute actually global between plasmoid instances (kde#418713)
  * Add portal.app_id to iconName lookup in pulseobject.cpp for flatpak
  * Move applet settings into KCM (kde#440846)
  * [kcm] Bundle icon for speakers test
  * applet: fix slider animation when toggling "Raise Maximum Volume"
  * applet: Surface middle-clickability in the UI
  * don't crash when the server doesn't respond (kde#454647,kde#437272)
  * KCM: Allow comboboxes to grow to fit contents (kde#458422)
  * KCM: Only show port/profile labels if port combobox is visible
  * Install po folder
  * Set bugReportURL for KCM
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- No code changes since 5.26.4
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- Changes since 5.26.3:
  * Install translated documentation from po/ too
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- No code changes since 5.26.2
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- No code changes since 5.26.1
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- Changes since 5.26.0:
  * don't crash when the server doesn't respond (kde#454647,kde#437272)
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- Changes since 5.25.90:
  * KCM: Allow comboboxes to grow to fit contents (kde#458422)
  * KCM: Only show port/profile labels if port combobox is visible
  * Install po folder
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Changes since 5.25.5:
  * applet: Make "Profiles" menu Translucent
  * applet: add more `KeyNavigation` properties
  * applet: Drop redundant workaround for semi-transparent sliders
  * applet: Support RTL layouts in volume slider
  * Add FreeBSD Qt6 CI support
  * Bump KF5_MIN_VERSION
  * Clean up unneeded json values from KCM metadata
  * Modernize KCM code
  * Add missing license file
  * KCM: Make list items shorter with changed layout
  * applet: fix menu key not working
  * applet: support arrow key navigation
  * applet: Animate slider when 'Raise maximum volume' is toggled
  * Remove unused QQC1 imports
  * VolumeMonitor: Don't set stream on source output monitor
  * applet: set role to ButtonMenu
  * applet: port to `PC3.ToolTip`
  * applet: add text to context menu button
  * applet: port to `PC3.ToolTip`
  * applet: add text to mute button
  * applet: Fix incompatible null binding to a string property
  * Remove extra ';'
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- No code changes since 5.25.4
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- Changes since 5.25.3:
  * VolumeMonitor: Don't set stream on source output monitor
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jul  5 2022 Antonio Larrosa <alarrosa@suse.com>
- Suggests pipewire-pulseaudio on TW instead of
  pulseaudio-module-x11 to make pipewire the default audio server.
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- No code changes since 5.25.1
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- No code changes since 5.25.0
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- No code changes since 5.24.90
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Changes since 5.24.5:
  * Modernize code
  * applet: Add fallback icons in device view and stream view
  * Initalise member variable
  * Remove duplicate header between header cpp file
  * SpeakerTest: Fix subwoofer test (kde#445523)
  * We need kf5.90 for building against qt6
  * Add Qt6 CI
  * applet: Fix logic to show virtual devices
  * gconf is long gone, always use gsettings
  * Add unmute message in both KCM and applet tooltip
  * [CI] Require passing unit tests
  * Speaker Test: Show playback errors in the UI
  * Applet: Hide virtual devices by default
  * Make compile against qt6
  * [kcm] Update device combobox when current device changes externally
  * Make distinction between audio level and audio meter clear
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- Changes since 5.24.4:
  * SpeakerTest: Fix subwoofer test (kde#445523)
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- Changes since 5.24.2:
  * [kcm] Update device combobox when current device changes externally
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- No code changes since 5.24.1
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- No code changes since 5.24.0
* Wed Feb  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop conditionals for no longer supported versions of openSUSE.
  Following this; drop pkgconfig(gconf-2.0) BuildRequires and
  (pulseaudio-module-gconf if pulseaudio) Recommends, and
  conditional cmake_kf5 call. Pulseaudio dropped support for gconf
  in version 15.
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- No code changes since 5.23.90
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Too many changes to list here
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- Changes since 5.23.4:
  * Fixes toggling Configure button on click.
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- No code changes since 5.23.3
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- No code changes since 5.23.0
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- Changes since 5.22.90:
  * [speakertest] Force canberra driver to PulseAudio (kde#442781)
  * Fix a bug that caused the handle of the volume slider to show artifacts (kde#434927)
  * Fix balance setting (kde#439751)
- Add supplements for pipewire-pulseaudio as well
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Changes since 5.22.5:
  * Add keywords to audio KCM
  * Integrate the advanced options under `Configure...` in the main page
  * Disable global mute when changing volume
  * [kcm] Avoid string puzzle
  * Explicitly set KDE_COMPILERSETTINGS_LEVEL
  * Remove unneeded target
  * [applet] Don't install as bundled package
  * [ListItemBase] Open menu on press
  * Remove unneeded X-KDE-PluginKeyword
  * [applet] Only set VolumeMonitor object if it's valid
  * Always disconnect streams (kde#439347)
  * [applet] Fix QML error
  * Use version-less qt DBus macros
  * Use ellipses instead of triple period
  * Set meta + mute as a default shortcut to mute the microphone
  * Support multiple default shortcuts
  * Fix crash when target is destroyed before monitor (kde#437184)
  * Indicate when application is "corked" (kde#398476)
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- Changes since 5.22.3:
  * [ListItemBase] Open menu on press
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- Changes since 5.22.2.1:
  * Always disconnect streams (kde#439347)
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- No code changes since 5.22.0
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- Changes since 5.21.90:
  * Set meta + mute as a default shortcut to mute the microphone
  * Support multiple default shortcuts
  * Fix crash when target is destroyed before monitor (kde#437184)
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Too many changes to list here
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- Changes since 5.21.4:
  * Increment volume by percent instead of a constant volumeStep (kde#434769,kde#435522)
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- Changes since 5.21.3:
  * Round volume to avoid increasing or decreasing by more than stepSize (kde#434769)
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- No code changes since 5.21.2
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- No code changes since 5.21.1
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- Changes since 5.21.0:
  * Unref stream after unsetting callbacks
* Thu Feb 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- Changes since 5.20.90:
  * Allow to mute/unmute microphone with left-click in system tray
  * [StreamRestore] Fix equals check
  * Forward role() into PulseObjectFilterModel
- Adjust dependencies to allow pipewire-pulseaudio as well
  (boo#1190768)
- Use GSettings on Leap 15.3+ as well
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Too many changes to list here
* Tue Jan  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.5
- Changes since 5.20.4:
  * [kcm] Read text color from proper theme
* Tue Dec  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.4
- Changes since 5.20.3:
  * Remove count property from PulseObjectFilterModel (kde#427978)
* Wed Nov 11 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.3
- No code changes since 5.20.2
* Tue Oct 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.2
- Changes since 5.20.1:
  * [applet] Remove unnecessary separator over menu section header (kde#427804)
* Tue Oct 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.1
- Changes since 5.20.0:
  * Bump Controls 2.14 in DeviceCombobox.qml
  * Correctly look up data in the model (kde#427687)
  * Simplify DeviceComboBox (kde#408700)
* Thu Oct  8 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.0
- No code changes since 5.19.90
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.90
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.90
- Changes since 5.19.5:
  * Default maximumPercent value of 100
  * Use pulseaudio's equal functions instead of memcmp
  * Show and hide the inactive device buttons based on new count property
  * Use i18nd consistently
  * don't show in widget explorer on plasma mobile
  * [applet] Allow showing inactive devices as in the KCM
  * [applet] Port towards PlasmaComponents3
  * Colorize volume percentage text when over 100%%
  * Show correct volume level in OSD when maximum volume is raised (kde#422537)
  * Filter out currently unused devices (kde#422612)
  * Fix Layout warnings
  * Take into account Balance button for layouting
  * Fix centering Volume icon around channel sliders
  * Change it to a "Balance" button so also non-geeks can comprehend it
  * Allow "unlocking" volume slider for per-channel (e.g. left, right) volume sliders
  * [ListItemBase] Open options menu also on right click like a context menu
* Tue Sep  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.5
- No code changes since 5.19.4
* Tue Jul 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.4
- No code changes since 5.19.3
* Tue Jul  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.3
- No code changes since 5.19.2
* Tue Jun 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.2
- No code changes since 5.19.1
* Tue Jun 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.1.php
- No code changes since 5.19.0
* Thu Jun  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.0.php
- No code changes since 5.18.90
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.90.php
- Changes since 5.18.5:
  * Converted to page and added heading
  * Add options for OSD feedback (kde#363983)
  * bump to require Qt 5.14
  * [KCM]Align volume controls row
  * [KCM]Update Device item layout based on applet (kde#417607)
  * [applet] For placeholder labels, disable rather than changing opacity
  * [Applet]Improvements for unavailable port.
  * [Applet]Correct raise max volume functions for mic
  * [Applet]Always get valid device and stream name
  * Fix minor EBN issue and typos
  * [Applet] Display device name when there is than one device (kde#417079)
  * [Applet]Fix device label problems (kde#417074,kde#417106)
  * [Applet]Supplementary add port check
  * [Applet]Add port check
  * [Applet] Remove leftover in config window
  * [Applet] Enable new global "Raise maximum volume" checkbox
  * [Applet]Hide hamburger menu when empty
  * [Applet]Add global mute function (kde#396835)
  * [Applet] Make 'raise maximum volume' global
  * [Applet]Update layout based on T10470
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- Changes since 5.18.4.1:
  * Create StreamRestore channel if none exists (kde#407397)
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- No code changes since 5.18.3
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- Changes since 5.18.2:
  * [KCM]Fix content below scrollbars (kde#416331,kde#417447)
  * [KCM]Set implicitWidth for main page
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- No code changes since 5.18.1
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- No code changes since 5.18.0
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- No code changes since 5.17.90
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Changes since 5.17.5:
  * KF5_MIN_VERSION for plasma 5.18 is KF5 5.66.0
  * [Applet] Fix empty space and give correct size
  * Make it compile without deprecated method
  * Add KDEClangFormat cmake support
  * Use a lighter star color for non-default devices
  * Increase UI commonality between KCM and applet
  * Fix wrong KCM device icon for specific form factors
  * Make KCM look more like applet
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- No code changes since 5.17.4
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- No code changes since 5.17.3
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- No code changes since 5.17.2
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- No code changes since 5.17.1
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- Changes since 5.17.0:
  * [Applet] Make spinboxes editable
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- Changes since 5.16.90:
  * Add X-KDE-FormFactors in the metadata.desktop as well
  * metadata: Add form factors to make kcm appear on mobile again
  * Fix kcmshell window being too small (kde#412087)
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Changes since 5.16.5:
  * update to latest kf5 dependency
  * Use visible buttons to switch the default device (kde#408490)
  * Set maximum volume of streams properly even if the user has configured a maximum volume <100%% in the applet.
  * Promote KCM to top level and rename accordingly
  * Allow to set maximum volume < 100%% (kde#404387)
  * Avoid garbling the sound if the volume slider is moved fast (kde#409525,kde#410716)
  * [KCM] Slightly improve tab bar's integration with frame
  * [Applet] Use the more user-friendly term "recording" instead of "capture"
  * Hide "Dummy Output" from output list and improve user-visible labels
  * Make feedback-related strings accurate
  * Fix forward declaration
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- Changes since 5.16.4:
  * Fix speaker test not showing sinks/buttons
  * [Microphone Indicator] Don't show if there are no microphones
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- No code changes since 5.16.3
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- Changes since 5.16.2:
  * [KCM] Use sourceSize for avatar to improve appearance and reduce memory consumption BUG: 409187 FIXED-IN: 5.16.2 (kde#409187)
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- No code changes since 5.16.1
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- No code changes since 5.16.0
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- No code changes since 5.15.90
* Mon May 20 2019 wbauer@tmo.at
- Only build with gsettings on Tumbleweed, Leap 15.0/15.1 don't
  have pulseaudio-module-gsettings yet
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Changes since 5.15.5:
  * bump Qt version to 5.12 as agreed at start of cycle
  * Fix build where GObject & deps libraries are not in default library path
  * Port widget settings window to QQC2+Kirigami FormLayout and modernize UI
  * [Microphone Indicator] Avoid duplicate application names
  * [Microphone Indicator] Schedule update initially
  * [Microphone Indicator] There's no virtual sources, just source outputs
  * Don't play sound when muting
  * [plasma-pa] Add command to switch all applications to the selected device
  * Don't abort when org.freedesktop.pulseaudio.module-group schema isn't installed
  * Define constants in cpp
  * Use own headers
  * Add microphone indicator
  * Port from GConf to GSettings
  * Use FindGLIB2 from ECM
  * port to ECM's FindCanberra
  * [plasma-pa] Increase minimum size of expanded plasmoid
  * [KCM] Port to QQC2 (kde#397954)
  * bump to cmake requirement to 3.5
  * find volume feedback's runtime requirements
  * Don't ignore default virtual devices
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- Changes since 5.15.4:
  * [Context] Update StreamRestore before inserting it
  * [StreamRestore] Don't mess with channels (kde#398392)
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- No code changes since 5.15.3
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- Changes since 5.15.2:
  * search our cmake dir first
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- No code changes since 5.15.0
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- Changes since 5.14.90:
  * [build] Search for kirigami as a runtime dependency
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * bump KF5 dependency to required 5.54 as agreed at start of Plasma 5.15 cycle
  * Use the nicer K_PLUGIN_CLASS_WITH_JSON
  * Revert 604f35edd4a14d630d4583f61eb8109f21b6ed3a
  * Make widget configuration translatable
  * Kirigami Pages are required for kcms
  * Show "muted" icon in panel and disable shortcuts for Dummy Output
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- No code changes since 5.14.4
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- Changes since 5.14.3:
  * Fix i18n when the kcm code is embedded in the plasmoid config
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- Changes since 5.14.2:
  * Set appropriate icon for plasmoid (kde#400586)
  * Fix connecting to PulseAudio with Qt 5.12 beta 3
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- No code changes since 5.14.1
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Sun Oct  7 2018 Jan Engelhardt <jengelh@inai.de>
- Remove time-sensitive wording of descriptions.
- Remove ldconfig as there are no shared library in %%_libdir.
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- No code changes since 5.13.90
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Changes since 5.13.5:
  * Use unpretty channel name in speakertest
  * QT_MIN_VERSIONS is Qt 5.11 for Plasma 5.14. Agreed at kickoff meeting.  Set everywhere for clearity and consistency.
  * Show "muted" icon for dummy output
  * Add .kdev4 to gitignore
  * Add QT_NO_KEYWORDS definition
  * [KCM] Add speaker placement test
  * Fix last merge - missing changes in src/CMakeLists.txt
  * Use non-deprecated KDEInstallDirs variables
  * Use more explicit
  * Use consistently nullptr
  * Use consistently override (or final where Q_DECL_FINAL was used)
  * No need to add ECM_KDE_MODULE_DIR, part of ECM_MODULE_PATH
  * Use more common QDebug include, not QtDebug
  * Remove Qt module prefix from include
  * Remove Qt module include
  * Use KF5_MIN_VERSION also for ECM, now that it's part of KF
  * Require KDE Frameworks 5.42 and Qt 5.9
  * Bump min cmake version to 3.0, move cmake_minimum_required to begin
  * Fix wrong availability of profiles and ports.
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * None
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * Make GConf optional dependency (kde#386665)
  * Fix wrong availability of profiles and ports.
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * Fix wrong availability of profiles and ports.
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * SinkModel: Ignore virtual sinks for preferredSink (kde#395466)
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * None
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.5:
  * Don't use plasma theme icons for application icons
  * Show OSD when default output changes
  * Fix issues in models to pass ModelTest
  * use the new install_package form
  * Simplify display when there's only a single input device and a single output device
  * Add "move to device" functionality to hamburger menu
  * KCM: Show only available device profiles
  * Fix output device context menu
  * Applet: Use new device icons
  * Move availability property from Port to Profile
* Fri May 11 2018 wbauer@tmo.at
- Recommend pulseaudio-module-gconf (boo#1092871)
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * AbstractModel: Check if index is valid in setData
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * call beginRemoveRows before removing the data
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * None
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * None
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * Support "phone" form factor
  * Applet: Fix accessing SourceModel from main item (kde#390161)
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * Fix drag cursor
  * Fix moving streams by drag and drop (kde#389402)
- Drop patches, now upstream:
  * 0001-Fix-moving-streams-by-drag-and-drop.patch
* Thu Jan 25 2018 fabian@ritter-vogt.de
- Add patch to fix channel drag-and-drop:
  * 0001-Fix-moving-streams-by-drag-and-drop.patch
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Changes since 5.11.5:
  * Move contents into fullRepresentation
  * Also try application.name to get iconName
  * Make device "master volume" the max of all channels instead of the avg
  * Remove obsolete reviewboardrc file
  * Fix uninitialized warning on valgrind
  * Show headset icons for devices identifying as "Headset" in Description
  * Remaining accessibility on Plasma PA
  * Put tabbar in focus chain
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * None
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * None
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * None
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * None
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * None
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * None
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Changes since 5.10.5:
  * [ListItemBase] Use section instead of disabled menu item
  * StreamRestore: Always set channel count to 1 (kde#383787)
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * Context: Return early from connectToDaemon when already connected (kde#381411)
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * Revert "Make the applet DBus activated" (kde#381010)
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * Don't call setDefaultSink/Source when already default (kde#380414)
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * None
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Too many changes to list here
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * None
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * None
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * StreamRestore: Cache values in writeChanges until receiving change from pa
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * None
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * Always check if context is valid when calling pa functions
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * VolumeSlider: Ignore all value changes until Component is completed
  * Fix compare for undefined argument in playFeedback()
  * Pass correct index to playFeedback
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * Show percentage in tooltip maintext and indicate when muted.
  * Applet: Make sure to never show empty icon.
  * Set mute when changing volume to 0 with slider.
  * Applet: Toggle mute of items with middle mouse button.
  * Applet: Don't delete delegates while drag is active. Fixes kde#374288
  * Remove the depreciated Plasma PopupApplet servicetype.
  * Fix comparing pa_cvolume objects. Fixes kde#373943
  * Correctly initialise and compare pa_cvolume structs.
  * Applet: Show device icons and active port name.
  * [Stream] Expose "corked" property.
  * Use microphone volume icon for capture devices/streams in applet.
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Fri Aug 12 2016 hrvoje.senjan@gmail.com
- Adjust filelist for the plasmoid appdata, installed with KF > 5.25.0
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Tue Jul  5 2016 wbauer@tmo.at
- Use the new %%kf5_find_lang macro to create the file list for the
  lang package
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Tue Aug 11 2015 hrvoje.senjan@gmail.com
- Initial package
